# Tastenkürzel — XED /TUI
> Englische Version: [../../docs/keybindings.md](../../docs/keybindings.md)

## Navigation

| Taste | Aktion |
|---|---|
| `↑` / `k` | Eine Zeile hoch |
| `↓` / `j` | Eine Zeile runter |
| `K` / `J` | 5 Zeilen hoch / runter |
| `PgUp` / `PgDn` | Seite hoch / runter |
| `Home` / `g` | Erste Zeile |
| `End` / `G` | Letzte Zeile |
| `Tab` | Panel wechseln (→) |
| `←` / `→` | Panel wechseln |
| `Enter` | Session öffnen |

## Sessions

| Taste | Aktion |
|---|---|
| `a` | Claude Code `--resume` starten |
| `r` | `/resume <uuid>` in Clipboard |
| `s` | Sessions neu laden |
| `t` | Titel setzen |
| `d` | Session löschen (Bestätigung: "delete" tippen) |
| `/` | Live-Suche |
| `#` | Tags setzen (komma-getrennt) · filtern mit `/#tag` |

## Reader + Notizen

| Taste | Aktion |
|---|---|
| `e` | Notiz im Editor öffnen (auto-detect / via `Ctrl+E` konfigurierbar) |
| `o` | Notiz in Standard-App öffnen (xdg-open / via `Ctrl+E` konfigurierbar) |
| `u` | Notiz mit neuen Turns aktualisieren (ohne Editor) |
| `c` | Notiz in Clipboard |
| `f` | Reader-Vollbild |
| `n` | Notiz-Vollbild |
| `m` | Panels tauschen (Move/Swap) |

## Layout

| Taste | Aktion |
|---|---|
| `0` | Top-Bereich ausblenden |
| `1`–`9` | Top-Höhe (n × 5 Zeilen) |
| `Ctrl+R` | Hot-Reload |
| `Ctrl+E` | Einstellungen: Editor und Standard-App |

## System

| Taste | Aktion |
|---|---|
| `?` | Hilfe anzeigen (DE / EN / FR / JA / ES — wechseln mit `←→`) |
| `q` / `Esc` | Zurück / Beenden |
